module SimpleCA
  class SignCSR
    THREE_YEARS = 365.25 * 24 * 60 * 60

    def initialize root, key
      @root = root
      @key = key
    end

    def call csr
      sign_cert(OpenSSL::X509::Certificate.new, csr)
    end

    private

    def sign_cert crt, request
      crt.serial = 0
      crt.version = 2
      crt.not_before = Time.now
      crt.not_after = Time.now + THREE_YEARS
      crt.subject = request.subject
      crt.public_key = request.public_key
      crt.issuer = @root.subject
      crt.sign @key, OpenSSL::Digest::SHA256.new
    end
  end
end
